@@ -1,11 +1,11 @@
-import uuid
 import os
+import uuid
 from importlib.util import module_from_spec, spec_from_file_location
 
 import orjson
-from flask import render_template, current_app, url_for
 from bs4 import BeautifulSoup
 from bs4.formatter import HTMLFormatter
+from flask import render_template, current_app, url_for, jsonify
 
 
 def convert_to_snake_case(s):
@@ -74,7 +74,7 @@ class Component:
             self._bind_form(kwargs)
 
     def __repr__(self):
-        return f"<meld.Component {self.__class__.__name__}-vars{self._attributes()})>"
+        return f"<meld.Component {self.__class__.__name__}>"
 
     @property
     def _meld_attrs(self):
@@ -194,9 +194,13 @@ class Component:
         pass
 
     def render(self, component_name):
-        return self._view(component_name, self._attributes())
+        return self._view(component_name)
 
-    def _view(self, component_name, data):
+    def _render_template(self, template_name: str, context_variables: dict):
+        return render_template(template_name, **context_variables)
+
+    def _view(self, component_name):
+        data = self._attributes()
         context = self.__context__()
         context_variables = {}
         context_variables.update(context["attributes"])
@@ -204,28 +208,22 @@ class Component:
         context_variables.update(data)
         context_variables.update({"form": self._form})
 
-        frontend_context_variables = {}
-        frontend_context_variables.update(context["attributes"])
-        frontend_context_variables = orjson.dumps(frontend_context_variables).decode(
-            "utf-8"
-        )
-        rendered_template = render_template(
-            f"meld/{component_name}.html", **context_variables
+        rendered_template = self._render_template(
+            f"meld/{component_name}.html", context_variables
         )
 
         soup = BeautifulSoup(rendered_template, features="html.parser")
         root_element = Component._get_root_element(soup)
         root_element["meld:id"] = str(self.id)
-        root_element["meld:data"] = frontend_context_variables
         self._set_values(root_element, context_variables)
 
         script = soup.new_tag("script", type="module")
-        init = {"id": str(self.id), "name": component_name, "data": data}
-        init = orjson.dumps(init).decode("utf-8")
+        init = {"id": str(self.id), "name": component_name, "data": jsonify(data).json}
+        init_json = orjson.dumps(init).decode("utf-8")
 
         meld_url = url_for("static", filename="meld/meld.js")
         meld_import = f'import {{Meld}} from ".{meld_url}";'
-        script.string = f"{meld_import} Meld.componentInit({init});"
+        script.string = f"{meld_import} Meld.componentInit({init_json});"
         root_element.append(script)
 
         rendered_template = Component._desoupify(soup)
@@ -236,10 +234,17 @@ class Component:
         """
         Set the value on model fields
         """
-        for element in soup.find_all(attrs={'meld:model': True}):
-            element.attrs["value"] = context_variables[
-                element.attrs["meld:model"]
+        for element in soup.select("input,select,textarea"):
+            model_attrs = [
+                attr for attr in element.attrs.keys() if attr.startswith("meld:model")
             ]
+            if len(model_attrs) > 1:
+                raise Exception(
+                    "Multiple 'meld:model' attributes not allowed on one tag."
+                )
+
+            for model_attr in model_attrs:
+                element.attrs["value"] = context_variables[element.attrs[model_attr]]
 
     @staticmethod
     def _get_root_element(soup):
